## 1.0.7 (2024-10-14)

### fixed (1 change)

- [Handle Proxmox errors better.](lucid/proxmox-info@f7b7bcd802eb1fa2dba1869283870e6cc99b7f06)

## 1.0.6 (2024-10-13)

### added (1 change)

- [Add 'human' CLI option](lucid/proxmox-info@c751276c95501dc81dcbc638cd86d35ddaa43594)

## 1.0.5 (2024-10-13)

### other (1 change)

- [Doco update/screenshots.](lucid/proxmox-info@00cdef8c2c668f61b21d698e6710cf708bd3644a)

## 1.0.3 (2024-10-13)

### added (1 change)

- [Pager support.](lucid/proxmox-info@644bf0915e36e61490afc4827369b09577fb607b)

## 1.0.2 (2024-10-09)

### fixed (1 change)

- More packaging issues

## 1.0.1 (2024-10-09)

### fixed (1 change)

- [Packaging issues](lucid/proxmox-info@3ac6f0a2ea48f96b6316361992ab498f9ef23f35)
